![Tests](https://github.com/fast-aircraft-design/FAST-OAD_CS25/workflows/Tests/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/fast-oad-cs25/badge/?version=stable)](https://fast-oad.readthedocs.io/)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/06d1fb8ee5c3429cb3cbb165413187bc)](https://www.codacy.com/gh/fast-aircraft-design/FAST-OAD_CS25/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=fast-aircraft-design/FAST-OAD_CS25&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/fast-aircraft-design/FAST-OAD_CS25/branch/master/graph/badge.
svg)](https://codecov.io/gh/fast-aircraft-design/FAST-OAD_CS25)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/fast-aircraft-design/FAST-OAD_CS25.git/latest-release?urlpath=lab%2Ftree%2Fsrc%2Ffastoad%2Fnotebooks)


FAST-OAD CS-25/FAR-25-related models
====================================

This package is a plugin for FAST-OAD (version 1.3 or above). It contains models related to classic
commercial transport aircraft.

Want to try quickly?
--------------------
You can run FAST-OAD-CS25 notebooks **without installation** using our
[Binder-hosted Jupyter notebooks](https://mybinder.org/v2/gh/fast-aircraft-design/FAST-OAD_CS25.git/latest-release?filepath=src%2Ffastoad%2Fnotebooks).


Install
-------

**Prerequisite**:FAST-OAD needs at least **Python 3.7.0**.

It is recommended (but not required) to do the install in a virtual
environment ([conda](https://docs.conda.io/en/latest/),
[venv](https://docs.python.org/3.7/library/venv.html), ...)

Once Python is installed, installation can be done using pip. FAST-OAD, the core software, will be
installed at the same time.

> **Note**: If your network uses a proxy, you may have to do [some
> settings](https://pip.pypa.io/en/stable/user_guide/#using-a-proxy-server)
> for pip to work correctly

You can install the latest version (including the main software FAST-OAD) with this command:

``` {.bash}
$ pip install --upgrade fast-oad-cs25
```
